@@ -7,13 +7,14 @@ use File::Temp;
 use MyApp::Form;
 
 __PACKAGE__->config(
-    primary_key => 'absolute',
-    form_class  => 'MyApp::Form',
-    form_fields => [qw( file content )],
-    model_name  => 'File',
-    primary_key => 'file',
-    init_form   => 'init_with_file',
-    init_object => 'file_from_form',
+    primary_key           => 'absolute',
+    form_class            => 'MyApp::Form',
+    form_fields           => [qw( file content )],
+    model_name            => 'File',
+    primary_key           => 'file',
+    init_form             => 'init_with_file',
+    init_object           => 'file_from_form',
+    view_on_single_result => 1,
 );
 
 # test the view_on_single_result method
@@ -31,7 +32,7 @@ sub do_search {
     my $file = $c->model( $self->model_name )
         ->new_object( file => $tmpf->filename );
 
-    if ( my $uri = $self->view_on_single_result( $c, [$file] ) ) {
+    if ( my $uri = $self->uri_for_view_on_single_result( $c, [$file] ) ) {
         $c->response->redirect($uri);
         return;
     }
